@@ -10,7 +10,7 @@ module Megatest
 
     class << self
       def run!
-        program_name = $PROGRAM_NAME
+        program_name = ENV.fetch("MEGATEST_PROGRAM_NAME", $PROGRAM_NAME)
         if paths = ENV["PATH"]
           paths.split(":").each do |path|
             if program_name.start_with?(path)
@@ -69,6 +69,8 @@ module Megatest
     end
 
     def configure
+      Megatest.running = true
+
       if @runner = RUNNERS[@argv.first]
         @argv.shift
       end
