@@ -91,6 +91,21 @@ module Megatest
         end
       end
       assert_equal 4, @result.assertions_count
+
+      @case.assert_raises(NotImplementedError, match: "token") do
+        raise NotImplementedError, "Contains some token."
+      end
+      assert_equal 5, @result.assertions_count
+    end
+
+    def test_assert_nothing_raised
+      @case.assert_nothing_raised { 1 + 1 }
+      assert_equal 1, @result.assertions_count
+
+      assert_raises UnexpectedError do
+        @case.assert_nothing_raised { 1.oops }
+      end
+      assert_equal 2, @result.assertions_count
     end
 
     def test_assert
@@ -535,6 +550,138 @@ module Megatest
       assert_equal 2, @result.assertions_count
     end
 
+    def test_assert_difference
+      assert_equal 0, @result.assertions_count
+
+      counter = 0
+      @case.assert_difference -> { counter } do
+        counter += 1
+      end
+      assert_equal 1, @result.assertions_count
+
+      matcher = if defined?(RubyVM::InstructionSequence)
+        "`counter` didn't change by 1, but by 2."
+      else
+        /Proc.* didn't change by 1, but by 2./
+      end
+
+      assert_failure_message(matcher) do
+        @case.assert_difference -> { counter } do
+          counter += 2
+        end
+      end
+      assert_equal 2, @result.assertions_count
+
+      assert_failure_message(/ didn't change by 3, but by 2./) do
+        @case.assert_difference -> { counter }, 3 do
+          counter += 2
+        end
+      end
+      assert_equal 3, @result.assertions_count
+
+      assert_failure_message(/ didn't change by 3, but by 2./) do
+        @case.assert_difference -> { counter }, 3 do
+          counter += 2
+        end
+      end
+      assert_equal 4, @result.assertions_count
+
+      assert_failure_message(/ didn't change by 1, but by 0./) do
+        @case.assert_difference [-> { counter }, "0"] do
+          counter += 1
+        end
+      end
+      assert_equal 5, @result.assertions_count
+
+      assert_failure_message(/ didn't change by 3, but by 0./) do
+        @case.assert_difference({ -> { counter } => 1, -> { 0 } => 3 }) do
+          counter += 1
+        end
+      end
+      assert_equal 6, @result.assertions_count
+    end
+
+    def test_refute_difference
+      assert_equal 0, @result.assertions_count
+
+      counter = 0
+      @case.refute_difference -> { counter } do
+      end
+      assert_equal 1, @result.assertions_count
+
+      assert_raises Assertion, match: /Expected .* to not change, but it changed from 0 to 1./ do
+        @case.refute_difference -> { counter } do
+          counter += 1
+        end
+      end
+      assert_equal 2, @result.assertions_count
+    end
+
+    def test_assert_changes
+      assert_equal 0, @result.assertions_count
+
+      counter = 0
+      @case.assert_changes -> { counter } do
+        counter += 1
+      end
+      assert_equal 1, @result.assertions_count
+
+      assert_raises Assertion, match: /Expected .* to change, but it stayed 1/ do
+        @case.assert_changes -> { counter } do
+        end
+      end
+      assert_equal 2, @result.assertions_count
+
+      assert_raises Assertion, match: /Expected .* to starts from 0, but was 1/ do
+        @case.assert_changes -> { counter }, from: 0, to: 1 do
+        end
+      end
+      assert_equal 3, @result.assertions_count
+
+      assert_raises Assertion, match: /Expected .* to change to 2, but it stayed 1/ do
+        @case.assert_changes -> { counter }, from: 1, to: 2 do
+        end
+      end
+      assert_equal 4, @result.assertions_count
+
+      @case.assert_changes -> { counter }, from: 1, to: 2 do
+        counter += 1
+      end
+      assert_equal 5, @result.assertions_count
+    end
+
+    def test_refute_changes
+      assert_equal 0, @result.assertions_count
+
+      counter = 0
+      @case.refute_changes -> { counter } do
+      end
+      assert_equal 1, @result.assertions_count
+
+      assert_raises Assertion, match: /Expected .* to not change, but it changed from 0 to 1./ do
+        @case.refute_changes -> { counter } do
+          counter += 1
+        end
+      end
+      assert_equal 2, @result.assertions_count
+
+      assert_raises Assertion, match: /Expected .* to start from 2, but was 1./ do
+        @case.refute_changes -> { counter }, from: 2 do
+        end
+      end
+      assert_equal 3, @result.assertions_count
+    end
+
+    def test_yielding_assertion
+      assert_raises UnexpectedError do
+        @case.assert_raises NotImplementedError do
+          @case.assert_difference -> { 0 }, 2 do
+            raise NotImplementedError
+          end
+        end
+      end
+    end
+
     def test_assert_operator
       assert_equal 0, @result.assertions_count
 
